==> vtigercrm-5.3.0p0.tgz: vtigercrm/modules/com_vtiger_workflow/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = array(
'VTEmailTask' => 'Send Email',
'VTEntityMethodTask' => 'Invoke Custom Function',
'VTCreateTodoTask' => 'Create Todo',
'VTCreateEventTask' => 'Create Event',
'VTSMSTask' => 'SMS Task',
'LBL_EDIT_TASK'=>'Edit Task',
'LBL_EDIT_TASK_TITLE'=>'Edit an existing task or create a new one',
'LBL_EDIT_WORKFLOW'=>'Edit Workflow',
'LBL_EDIT_WORKFLOW_TITLE'=>'Edit an existing workflow or create a one',
'LBL_FROM_TEMPLATE'=>'From Template',
'LBL_NEW_WORKFLOW'=>'New Workflow',
'LBL_NEW_TEMPLATE'=>'Save as Template',
'LBL_CREATE_WORKFLOW_FOR'=>'Create a workflow for',
'LBL_FOR_MODULE'=>'For Module',
'LBL_CHOOSE_A_TEMPLATE'=>'Choose a template',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'There are empty mandatory fields.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'Start date/time is greater than the end date/time',
'LBL_ERROR_NO_WORKFLOW'=>'The workflow you requested does not exist',
'LBL_ERROR_NO_TASK'=>'The task you requested does not exist',
'LBL_ERROR_NOT_ADMIN'=>'You do not have access to this module as you are not an admin user',
'LBL_CREATE_WORKFLOW'=>'Create workflow',
'LBL_WORKFLOW_LIST'=>'Workflow List',
'LBL_AVAILABLE_WORKLIST_LIST'=>'Available Workflows',
'LBL_LOADING'=>'Loading...',
'LBL_VALIDATION_ERROR'=>'Validation Error',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Select Option...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'NOTE: You should have Workflow cron script configured.',
'LBL_NO_TEMPLATES'=>'No Templates',
'LBL_SELECT'=>'Select',
'LBL_MESSAGE'=>'Message',
'LBL_SET_FIELD_VALUES'=>'Set Field Values',
'LBL_ADD_FIELD'=>'Add Field',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- Use Field Value --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Use Function --',

'LBL_RAW_TEXT'=>'Raw Text',
'LBL_FIELD'=>'Field',
'LBL_EXPRESSION'=>'Expression',
'LBL_SET_EXPRESSION'=>'Set Expression',

'LBL_MANUAL'=>'System',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'New Condition Group',

'VTUpdateFieldsTask' => 'Update Fields',


'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'Same field selected more than once.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Invalid field values',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Note: Expressions will be evaluated in the order of the field values provided.
											So make sure to provide value for a field before using it in expressions.',
'LBL_SET_VALUE' => 'Set Value',

'LBL_EMAIL_RECIPIENT' => 'Recipient',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Subject',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Note: All the date, time and recurring information configured for the event,
													will be with respect to default time zone, configured in config.inc.php',
	
);


?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/com_vtiger_workflow/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = array(
'VTEmailTask' => 'Send Email',
'VTEntityMethodTask' => 'Invoke Custom Function',
'VTCreateTodoTask' => 'Create Todo',
'VTCreateEventTask' => 'Create Event',
'VTSMSTask' => 'SMS Task',
'LBL_EDIT_TASK'=>'Edit Task',
'LBL_EDIT_TASK_TITLE'=>'Edit an existing task or create a new one',
'LBL_EDIT_WORKFLOW'=>'Edit Workflow',
'LBL_EDIT_WORKFLOW_TITLE'=>'Edit an existing workflow or create a one',
'LBL_FROM_TEMPLATE'=>'From Template',
'LBL_NEW_WORKFLOW'=>'New Workflow',
'LBL_NEW_TEMPLATE'=>'Save as Template',
'LBL_CREATE_WORKFLOW_FOR'=>'Create a workflow for',
'LBL_FOR_MODULE'=>'For Module',
'LBL_CHOOSE_A_TEMPLATE'=>'Choose a template',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'There are empty mandatory fields.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'Start date/time is greater than the end date/time',
'LBL_ERROR_NO_WORKFLOW'=>'The workflow you requested does not exist',
'LBL_ERROR_NO_TASK'=>'The task you requested does not exist',
'LBL_ERROR_NOT_ADMIN'=>'You do not have access to this module as you are not an admin user',
'LBL_CREATE_WORKFLOW'=>'Create workflow',
'LBL_WORKFLOW_LIST'=>'Workflow List',
'LBL_AVAILABLE_WORKLIST_LIST'=>'Available Workflows',
'LBL_LOADING'=>'Loading...',
'LBL_VALIDATION_ERROR'=>'Validation Error',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Select Option...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'NOTE: You should have Workflow cron script configured.',
'LBL_NO_TEMPLATES'=>'No Templates',
'LBL_SELECT'=>'Select',
'LBL_MESSAGE'=>'Message',
'LBL_SET_FIELD_VALUES'=>'Set Field Values',
'LBL_ADD_FIELD'=>'Add Field',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- Use Field Value --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Use Function --',

'LBL_RAW_TEXT'=>'Raw Text',
'LBL_FIELD'=>'Field',
'LBL_EXPRESSION'=>'Expression',
'LBL_SET_EXPRESSION'=>'Set Expression',

'LBL_MANUAL'=>'System',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'New Condition Group',

'VTUpdateFieldsTask' => 'Update Fields',


'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'Same field selected more than once.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Invalid field values',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Note: Expressions will be evaluated in the order of the field values provided.
											So make sure to provide value for a field before using it in expressions.',
'LBL_SET_VALUE' => 'Set Value',

'LBL_EMAIL_RECIPIENT' => 'Recipient',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Subject',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Note: All the date, time and recurring information configured for the event,
													will be with respect to default time zone, configured in config.inc.php',

'Select Meta Variables' => 'Select Meta Variables',
'Current Date' => 'Current Date',
'Current Time' => 'Current Time',
'System Timezone' => 'System Timezone',
'CRM Detail View URL' => 'CRM Detail View URL',
'Portal Detail View URL' => 'Portal Detail View URL',
'Site Url' => 'Site Url',
'Portal Url' => 'Portal Url',

'Workflow'=>'Workflow',

'VTCreateEntityTask' => 'Create Entity',
'LBL_ENTITY_TYPE' => 'Entity Type',
'LBL_SELECT_ENTITY_TYPE' => '-- Select Entity Type --',
'LBL_NO_ENTITIES_FOUND' => 'No Entities Found to Create',
);


?>
